@@ -19,10 +19,10 @@ $Data{'language'}{'iso2'}{'orig'}{'name'} = {
 };
 
 $Data{'language'}{'iso2'}{'ignore'} = {
-   "name"    => {},
-   "alpha2"  => {},
-   "alpha3"  => {},
-   "term"    => {},
+   "name"     => {},
+   "alpha-2"  => {},
+   "alpha-3"  => {},
+   "term"     => {},
 };
 
 ################################################################################
@@ -33,8 +33,8 @@ $Data{'language'}{'iso5'}{'orig'}{'name'} = {
 };
 
 $Data{'language'}{'iso5'}{'ignore'} = {
-   "name"    => {},
-   "alpha3"  => {},
+   "name"     => {},
+   "alpha-3"  => {},
 };
 
 ################################################################################
@@ -468,8 +468,8 @@ $Data{'language'}{'iana'}{'ignore'} = {
    "name"    => {
                  "Private use"      => 1,
                 },
-   "alpha2"  => {},
-   "alpha3"  => {},
+   "alpha-2" => {},
+   "alpha-3" => {},
 };
 
 1;
